==> owncloud-8.1.0p2.tgz: owncloud/apps/files_sharing/l10n/bg_BG.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Споделяне между сървъри не е разрешено на този сървър.",
    "The mountpoint name contains invalid characters." : "Името на mountpoint-a съдържа невалидни символи.",
    "Invalid or untrusted SSL certificate" : "Невалиден или ненадежден SSL сертификат",
    "Could not authenticate to remote share, password might be wrong" : "Неуспешно автентициране към отсрещната страна, паролата може да е грешна",
    "Storage not valid" : "Невалидно дисково пространство.",
    "Couldn't add remote share" : "Неуспешно добавяне на отдалечена споделена директория.",
    "Shared with you" : "Споделено с теб",
    "Shared with others" : "Споделено с други",
    "Shared by link" : "Споделено с връзка",
    "Nothing shared with you yet" : "Все още няма нищо споделено с теб",
    "Files and folders others share with you will show up here" : "Файлове и папки, споделени от други с теб, ще се показват тук",
    "Nothing shared yet" : "Още нищо не е споделено",
    "Files and folders you share will show up here" : "Файлове и папки, които ти споделяшм ще се показват тук.",
    "No shared links" : "Няма споделени връзки",
    "Files and folders you share by link will show up here" : "Файлове и директории, които ти споделяш чрез връзки, ще се показват тук",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Желаеш ли да добавиш като прикачената папка {name} от {owner}@{remote}?",
    "Remote share" : "Прикачена Папка",
    "Remote share password" : "Парола за прикачена папка",
    "Cancel" : "Отказ",
    "Add remote share" : "Добави прикачена папка",
    "No ownCloud installation (7 or higher) found at {remote}" : "Не е открита ownCloud ( 7 или по-висока ) инсталация на {remote}.",
    "Invalid ownCloud url" : "Невалиден ownCloud интернет адрес.",
    "Share" : "Сподели",
    "Shared by" : "Споделено от",
    "A file or folder has been <strong>shared</strong>" : "Файл или папка беше <strong>споделен/а</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Файл или папка е споделен от  <strong>друг сървър</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Публично споделен файл или папка е  <strong>изтеглен</strong>",
    "%1$s unshared %2$s from you" : "%1$s спря споделянето на %2$s с теб",
    "Public shared folder %1$s was downloaded" : "Публично споделената папка %1$s бе изтеглена",
    "Public shared file %1$s was downloaded" : "Публично споделения файл %1$s бе изтеглен",
    "You shared %1$s with %2$s" : "Вие споделихте %1$s с %2$s.",
    "You shared %1$s with group %2$s" : "Вие споделихте %1$s с групата %2$s.",
    "%2$s shared %1$s with you" : "%2$s сподели %1$s с Вас.",
    "You shared %1$s via link" : "Вие споделихте %1$s посредством връзка.",
    "Shares" : "Споделени Папки",
    "This share is password-protected" : "Тази зона е защитена с парола.",
    "The password is wrong. Try again." : "Грешна парола. Опитай отново.",
    "Password" : "Парола",
    "No entries found in this folder" : "Няма намерени записи в тази директория",
    "Name" : "Име",
    "Share time" : "Споделено на",
    "Sorry, this link doesn’t seem to work anymore." : "Съжаляваме, връзката вече не е активна.",
    "Reasons might be:" : "Причините може да са:",
    "the item was removed" : "съдържанието е премахнато",
    "the link expired" : "връзката е изтекла",
    "sharing is disabled" : "споделянето е изключено",
    "For more info, please ask the person who sent this link." : "За повече информация, моля питай човека, който е изпратил тази връзка.",
    "Add to your ownCloud" : "Добави към своя ownCloud",
    "Download" : "Изтегли",
    "Download %s" : "Изтегли %s",
    "Direct link" : "Директна връзка",
    "Allow users on this server to send shares to other servers" : "Позволи на потребители от този сървър да споделят папки  с други сървъри",
    "Allow users on this server to receive shares from other servers" : "Позволи на потребители на този сървър да получават споделени папки от други сървъри"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/bg_BG.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Споделяне между сървъри не е разрешено на този сървър.",
    "The mountpoint name contains invalid characters." : "Името на mountpoint-a съдържа невалидни символи.",
    "Invalid or untrusted SSL certificate" : "Невалиден или ненадежден SSL сертификат",
    "Could not authenticate to remote share, password might be wrong" : "Неуспешно автентициране към отсрещната страна, паролата може да е грешна",
    "Storage not valid" : "Невалидно дисково пространство.",
    "Couldn't add remote share" : "Неуспешно добавяне на отдалечена споделена директория.",
    "Shared with you" : "Споделено с теб",
    "Shared with others" : "Споделено с други",
    "Shared by link" : "Споделено с връзка",
    "Nothing shared with you yet" : "Все още няма нищо споделено с теб",
    "Files and folders others share with you will show up here" : "Файлове и папки, споделени от други с теб, ще се показват тук",
    "Nothing shared yet" : "Още нищо не е споделено",
    "Files and folders you share will show up here" : "Файлове и папки, които ти споделяшм ще се показват тук.",
    "No shared links" : "Няма споделени връзки",
    "Files and folders you share by link will show up here" : "Файлове и директории, които ти споделяш чрез връзки, ще се показват тук",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Желаеш ли да добавиш като прикачената папка {name} от {owner}@{remote}?",
    "Remote share" : "Прикачена Папка",
    "Remote share password" : "Парола за прикачена папка",
    "Cancel" : "Отказ",
    "Add remote share" : "Добави прикачена папка",
    "No ownCloud installation (7 or higher) found at {remote}" : "Не е открита ownCloud ( 7 или по-висока ) инсталация на {remote}.",
    "Invalid ownCloud url" : "Невалиден ownCloud интернет адрес.",
    "Shared by" : "Споделено от",
    "Sharing" : "Споделяне",
    "A file or folder has been <strong>shared</strong>" : "Файл или папка беше <strong>споделен/а</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Файл или папка е споделен от  <strong>друг сървър</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Публично споделен файл или папка е  <strong>изтеглен</strong>",
    "%1$s unshared %2$s from you" : "%1$s спря споделянето на %2$s с теб",
    "Public shared folder %1$s was downloaded" : "Публично споделената папка %1$s бе изтеглена",
    "Public shared file %1$s was downloaded" : "Публично споделения файл %1$s бе изтеглен",
    "You shared %1$s with %2$s" : "Вие споделихте %1$s с %2$s.",
    "You shared %1$s with group %2$s" : "Вие споделихте %1$s с групата %2$s.",
    "You shared %1$s via link" : "Вие споделихте %1$s посредством връзка.",
    "%2$s shared %1$s with you" : "%2$s сподели %1$s с Вас.",
    "Shares" : "Споделени Папки",
    "This share is password-protected" : "Тази зона е защитена с парола.",
    "The password is wrong. Try again." : "Грешна парола. Опитай отново.",
    "Password" : "Парола",
    "No entries found in this folder" : "Няма намерени записи в тази директория",
    "Name" : "Име",
    "Share time" : "Споделено на",
    "Sorry, this link doesn’t seem to work anymore." : "Съжаляваме, връзката вече не е активна.",
    "Reasons might be:" : "Причините може да са:",
    "the item was removed" : "съдържанието е премахнато",
    "the link expired" : "връзката е изтекла",
    "sharing is disabled" : "споделянето е изключено",
    "For more info, please ask the person who sent this link." : "За повече информация, моля питай човека, който е изпратил тази връзка.",
    "Add to your ownCloud" : "Добави към своя ownCloud",
    "Download" : "Изтегли",
    "Download %s" : "Изтегли %s",
    "Direct link" : "Директна връзка",
    "Allow users on this server to send shares to other servers" : "Позволи на потребители от този сървър да споделят папки  с други сървъри",
    "Allow users on this server to receive shares from other servers" : "Позволи на потребители на този сървър да получават споделени папки от други сървъри",
    "Public shared file %1$s was downloaded" : "Публично споделения файл %1$s бе изтеглен",
    "Public shared folder %1$s was downloaded" : "Публично споделената папка %1$s бе изтеглена"
},
"nplurals=2; plural=(n != 1);");
